function [S,R]=trapetsi(f,a,b,n,M2)
% Syötteet:  f   - integroitava funktio, tiedostossa vaikkapa intfun.m
%            a,b - v{lin p{{tepisteet
%            n - "pikkuv{lien lkm. parillinen 
%            M2: f'':n itseisarvon. max
%            
% Tulokset [S,R]=('intfun',a,b,n)  palauttaa:
%            S - integraalin trapetsiapproksimaatio
%            R - Virhearvio
%            S = ('intfun',a,b,n)  palauttaa pelkän S:n (tottakai!)
if nargin == 4
  M2=inf;         %  Siitäs saat, jos olet niin typerä, että kutsut kahdella
end;              %  paluuargumentoilla, vaikket anna M2:ta
if nargin == 3    % Jos ei anneta n:ää, käytetään arvoa n=10.
  n=10;
end;
h=(b-a)/n;
w=[0.5,ones(1,n-1),0.5];
x=a:h:b;
y=feval(f,x);
S=h*w*y';
if nargout==2
  R=(M2*(b-a)*h^2)/12;
end;
